<template>
  <SidebarLayout :navigation="navigation">
    <slot />
    <template #bottom>
      <template v-if="hasPermission(Permission.LINKS_VIEW, Permission.LINKS_CREATE, Permission.LINKS_UPDATE, Permission.LINKS_DELETE)">
        <ul
          class="-mx-2 mb-4 mt-auto space-y-1"
          role="list"
        >
          <RouterLink
            :to="{ name: 'dashboard' }"
            class="group flex items-center gap-x-3 rounded-md fill-current p-2 text-sm font-semibold leading-6 text-gray-400 hover:bg-gray-800 hover:text-white focus:outline-none focus:ring-2 focus:ring-white"
          >
            <GaugeRegularIcon
              aria-hidden="true"
              class="h-5 w-5 shrink-0"
            />
            {{ $t("app.dashboard.title") }}
          </RouterLink>
        </ul>
      </template>
    </template>
  </SidebarLayout>
</template>

<script lang="ts" setup>
import SidebarLayout from "@/js/contexts/shared/ui/layouts/SidebarLayout.vue";
import ChartLineRegularIcon from "@/svg/icons/chart-line-regular.svg?component";
import GaugeRegularIcon from "@/svg/icons/gauge-regular.svg?component";
import UserGroupRegularIcon from "@/svg/icons/user-group-regular.svg?component";
import AddressCardRegularIcon from "@/svg/icons/address-card-regular.svg?component";
import GearRegularIcon from "@/svg/icons/gear-regular.svg?component";
import GlobeRegularIcon from "@/svg/icons/globe-regular.svg?component";
import LinkRegularIcon from "@/svg/icons/link-regular.svg?component";
import useAuth from "@/js/contexts/auth/composables/useAuth";
import { Permission } from "@/js/contexts/shared/models/Permission";

const { t } = useI18n();
const { hasPermission } = useAuth();

const navigation = computed(() =>
  [
    {
      name: t("app.admin.analytics.title"),
      to: { name: "admin.analytics" },
      icon: ChartLineRegularIcon,
      hasPermission: hasPermission(Permission.ADMIN_ANALYTICS),
    },
    {
      name: t("app.admin.links.title"),
      to: { name: "admin.links" },
      icon: LinkRegularIcon,
      hasPermission: hasPermission(Permission.ADMIN_LINKS_VIEW, Permission.ADMIN_LINKS_UPDATE, Permission.ADMIN_LINKS_DELETE),
    },
    {
      name: t("app.admin.users.title"),
      to: { name: "admin.users" },
      icon: UserGroupRegularIcon,
      hasPermission: hasPermission(Permission.ADMIN_USERS_VIEW, Permission.ADMIN_USERS_CREATE, Permission.ADMIN_USERS_UPDATE, Permission.ADMIN_USERS_DELETE),
    },
    {
      name: t("app.admin.user_roles.title"),
      to: { name: "admin.user_roles" },
      icon: AddressCardRegularIcon,
      hasPermission: hasPermission(Permission.ADMIN_USER_ROLES_VIEW, Permission.ADMIN_USER_ROLES_CREATE, Permission.ADMIN_USER_ROLES_UPDATE, Permission.ADMIN_USER_ROLES_DELETE),
    },
    {
      name: t("app.admin.domains.title"),
      to: { name: "admin.domains" },
      icon: GlobeRegularIcon,
      hasPermission: hasPermission(Permission.ADMIN_DOMAINS_VIEW, Permission.ADMIN_DOMAINS_CREATE, Permission.ADMIN_DOMAINS_UPDATE, Permission.ADMIN_DOMAINS_DELETE),
    },
    {
      name: t("app.admin.settings.title"),
      to: { name: "admin.settings" },
      icon: GearRegularIcon,
      hasPermission: hasPermission(
        Permission.ADMIN_SETTINGS_GENERAL,
        Permission.ADMIN_SETTINGS_SEO,
        Permission.ADMIN_SETTINGS_APPEARANCE,
        Permission.ADMIN_SETTINGS_AUTHENTICATION,
        Permission.ADMIN_SETTINGS_OUTGOING_MAIL,
      ),
    },
  ].filter((item) => item.hasPermission),
);
</script>
